from distutils.core import setup


setup(
	name		= 'print_list',
	version 	= '1.1.1',
	py_modules	= ['print_list'],
	author		= 'erik',
	author_email	= 'nindoone@gmail.com',
	url		= 'undefined',
	description	= 'Prints lists in lists',

	)
